==> buildbot_grid_view-3.11.5.tar.gz: buildbot_grid_view-3.11.5/setup.py <==
#!/usr/bin/env python
#
# This file is part of Buildbot.  Buildbot is free software: you can
# redistribute it and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation, version 2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 51
# Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Copyright Buildbot Team Members

try:
    from buildbot_pkg import setup_www_plugin
except ImportError:
    import sys
    print('Please install buildbot_pkg module in order to install that '
          'package, or use the pre-build .whl modules available on pypi',
          file=sys.stderr)
    sys.exit(1)

setup_www_plugin(
    name='buildbot-grid-view',
    description='Buildbot Grid View plugin',
    author=u'Robin Jarry',
    author_email=u'robin.jarry@6wind.com',
    url='http://buildbot.net/',
    packages=['buildbot_grid_view'],
    package_data={
        '': [
            'VERSION',
            'static/*'
        ]
    },
    entry_points="""
        [buildbot.www]
        grid_view = buildbot_grid_view:ep
    """,
    classifiers=[
        'License :: OSI Approved :: GNU General Public License v2 (GPLv2)'
    ],
)

==> buildbot_grid_view-4.0.3.tar.gz: buildbot_grid_view-4.0.3/setup.py <==
#!/usr/bin/env python
#
# This file is part of Buildbot.  Buildbot is free software: you can
# redistribute it and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation, version 2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 51
# Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Copyright Buildbot Team Members

try:
    from buildbot_pkg import setup_www_plugin
except ImportError:
    import sys

    print(
        'Please install buildbot_pkg module in order to install that '
        'package, or use the pre-build .whl modules available on pypi',
        file=sys.stderr,
    )
    sys.exit(1)

setup_www_plugin(
    name='buildbot-grid-view',
    description='Buildbot Grid View plugin',
    author='Robin Jarry',
    author_email='robin.jarry@6wind.com',
    url='http://buildbot.net/',
    packages=['buildbot_grid_view'],
    package_data={'': ['VERSION', 'static/*', 'static/assets/*']},
    entry_points="""
        [buildbot.www]
        grid_view = buildbot_grid_view:ep
    """,
    classifiers=['License :: OSI Approved :: GNU General Public License v2 (GPLv2)'],
)
